# spfy

-----

**Table of Contents**

* [Installation](#installation)
* [License](#license)

## Installation

spfy is distributed on [PyPI](https://pypi.org) as a universal
wheel and is available on Linux/macOS and Windows and supports
Python 3.6+ and PyPy.

```bash
$ pip install spfy
```

## License

spfy is distributed under the terms of both

- [MIT License](https://choosealicense.com/licenses/mit)
- [Apache License, Version 2.0](https://choosealicense.com/licenses/apache-2.0)

at your option.
